#!/bin/bash

set -eu -o pipefail

MYDIR=$(dirname "$0")
. "$MYDIR/common.sh"

dump_path="${2:-}"
if [ ! -f "$dump_path" ]; then
	echo "File '$dump_path' not found"
	exit 1
fi

docker-compose down

docker-compose up -d pgnode1

# wait until PG is fully up
sleep 10

dump_filename=$(basename "$dump_path")
docker cp "$dump_path" "${compose_name}_pgnode1_1:/tmp/"
for db in instancecfg mediafiledata openslides; do 
	docker-compose exec -u postgres pgnode1 psql -f "/tmp/$dump_filename"
done

docker-compose exec -u postgres -T pgnode1 /bin/bash <<"EOF"
  umask 077
  psql -qAt0 instancecfg <<< "
    SELECT DISTINCT ON (filename, access) filename FROM dbcfg
    WHERE 'repmgr' = ANY (access)
    ORDER BY filename, access, id DESC;" |
  while IFS= read -r -d $'\0' target_filename; do
    echo "Fetching ${target_filename} from database."
    psql -d instancecfg -qtA <<< "
      SELECT DISTINCT ON (filename, access) data FROM dbcfg
        WHERE filename = '${target_filename}'
        AND   'repmgr' = ANY (access)
        ORDER BY filename, access, id DESC;
      " | xxd -r -p > "${target_filename}"
  done
EOF
